# Demonstration du logiciel libre R effectue par Pierre Casadebaig (pierre.casa@gmail.com)
# lors d'une prsentation bimensuelle de Toulibre le 24/01/2007

# Repertoire de travail
wd<-"/Users/picasa/Documents/Travail/Enseignement/2006-2007/Toulibre-R/"
setwd(wd)



# Manipulations d'objets
o=read.table("travelling.txt")
colnames(o)=c("n","t")
# Cration d'une variable "sequence"
s=which((o$n==0))
s=c(s, length(o$n)+1)
s=s[-1] - s[-length(s)]
s=rep(1:13, s)
o=cbind(s=as.factor(s),o)
# Graphiques et Statistiques Descriptives
library(lattice)
xyplot(
  t ~ n, data=o, groups = s, 
  type ='l', 
  auto.key=list(space="right", lines=T, points=F), 
  main="t=f(n) selon les squences"
)
xyplot(t ~ n | s,data=o, type="l")
summary(o)
hist(o$t)
hist(o$t[o$s==2], main="Distribution des temps/image de la sequence #2")
boxplot(t ~ s, data=o)
o.mean=tapply(o$t, o$s, mean)
o.max=tapply(o$t, o$s, max)


# Regression linaire simple
# Donnes et graphiques
d<-read.table("surfaces.txt", header=T)
plot(SF ~ Lxl, data=d)
# Modle linaire
m<-lm(SF ~ Lxl, data=d)
summary(m)
names(m)
plot(m$residuals)
plot(SF ~ Lxl, data=d, xlab="Longueur x largeur (cm)", ylab="Surface (cm)")
abline(m, lty=2)
legend("topleft", paste(c("b =","a ="), round(m$coefficient, 3)), bty="n")
# Observ/Predit
rmse=sqrt(sum((d$SF - m$fit)^2))


# Modles linaires varitaux
par(mfrow=c(4,4))
ylim=c(0, 800) ; xlim=c(0, 1500)
coefs=NULL
for (var in levels(d$Variete)) {
    m<-lm(SF ~ Lxl, data=d[d$Variete==var,])
    plot(SF ~ Lxl, data=d[d$Variete==var,], main=var, xlim=xlim, ylim=ylim) ; abline(m, lty=2)
    legend("bottomright", paste(c("b =","a ="), round(m$coefficient, 3)), bty="n")
    coefs=rbind(coefs, data.frame(variete=var, b=m$coefficients[1], a=m$coefficients[2], row.names=""))
}


# Regression non linaire
p=read.table("profils.txt", header=T, fill=T)
# Estimation des paramtres du modle (algorithme de Gauss-Newton)
x<-p$n
y<-p$p1
m=nls(y ~ max(na.omit(y))*exp(a*(x-xfe)^2 + b*(x-xfe)^3), start=list(xfe=20, a=-0.001, b=-0.0001))
# Graphiques
plot(y~x, xlab="Nombre de feuilles", ylab="Surface unitaire (cm)", main="Profil Foliaire")
lines(predict(m))
legend("topleft", paste(c("xfe =","a =","b ="), round(coef(m),4)), bty="n")




# Modles linaires
a<-read.table("architecture.txt", header=T)
pairs(a[,5:9])
cor(a[,5:9])
m<-lm(SFT ~ NF + SFFE + XFE + Haut, data=a)
plot(m$fit ~ SFT, data=a, xlab="Surface Mesure", ylab="Surface Simule") ; abline(0,1)
legend("topleft", paste("R =", round(summary(m)$r.squared, 3)), bty="n")
# Modle Parcimonieux
m2=step(m)
quartz()
plot(m2$fit ~ SFT, data=a, xlab="Surface Mesure", ylab="Surface Simule") ; abline(0,1)
legend("topleft", paste("R =", round(summary(m2)$r.squared, 3)), bty="n")

# Test de moyenne & Analyse de variance
r<-read.table("rendement.txt", header=T)
boxplot(Rendement ~ Milieu, data=r)
t.test(Rendement ~ Milieu, data=r)
boxplot(LAI ~ Milieu, data=r)
t.test(LAI ~ Milieu, data=r)
# Anova : t test gnraliss
summary(aov(Rendement ~ Genotype + Milieu, data=r))
summary(aov(Rendement ~ Genotype * Milieu, data=r))


